@@ -18,13 +18,13 @@ NULL
 #' @export
 #'
 #' @examples
-#' ht <- hux(a = 1:5, b = 1:5, d = 1:5)
-#' ht <- add_footnote(ht, '* this is a footnote')
-#' ht
+#' jams <- add_footnote(jams,
+#'       "* subject to availability")
+#' jams
 add_footnote <- function(ht, text, border = 0.8, ...) {
   nr <- nrow(ht) + 1
   nc <- ncol(ht)
-  ht <- rbind(ht, rep('', nc), copy_cell_props = FALSE)
+  ht <- rbind(ht, rep("", nc), copy_cell_props = FALSE)
   ht[nr, 1] <- text
   colspan(ht)[nr, 1] <- nc
   ht <- set_left_border(ht, nr, 1, 0)
@@ -54,37 +54,37 @@ add_footnote <- function(ht, text, border = 0.8, ...) {
 #' @export
 #'
 #' @examples
-#' foo <- 'Make $$$ with us'
-#' sanitize(foo, type = 'latex')
-sanitize <- function (str, type = c('latex', 'html', 'rtf')) {
+#' txt <- "Make $$$ with us"
+#' sanitize(txt, type = "latex")
+sanitize <- function (str, type = c("latex", "html", "rtf")) {
   type <- match.arg(type)
   result <- str
 
-  if (type == 'latex') {
-    result <- gsub('\\\\', 'SANITIZE.BACKSLASH', result)
-    result <- gsub('$', '\\$', result, fixed = TRUE)
-    result <- gsub('>', '$>$', result, fixed = TRUE)
-    result <- gsub('<', '$<$', result, fixed = TRUE)
-    result <- gsub('|', '$|$', result, fixed = TRUE)
-    result <- gsub('{', '\\{', result, fixed = TRUE)
-    result <- gsub('}', '\\}', result, fixed = TRUE)
-    result <- gsub('%', '\\%', result, fixed = TRUE)
-    result <- gsub('&', '\\&', result, fixed = TRUE)
-    result <- gsub('_', '\\_', result, fixed = TRUE)
-    result <- gsub('#', '\\#', result, fixed = TRUE)
-    result <- gsub('^', '\\verb|^|', result, fixed = TRUE)
-    result <- gsub('~', '\\~{}', result, fixed = TRUE)
-    result <- gsub('SANITIZE.BACKSLASH', '$\\backslash$',
+  if (type == "latex") {
+    result <- gsub("\\\\", "SANITIZE.BACKSLASH", result)
+    result <- gsub("$", "\\$", result, fixed = TRUE)
+    result <- gsub(">", "$>$", result, fixed = TRUE)
+    result <- gsub("<", "$<$", result, fixed = TRUE)
+    result <- gsub("|", "$|$", result, fixed = TRUE)
+    result <- gsub("{", "\\{", result, fixed = TRUE)
+    result <- gsub("}", "\\}", result, fixed = TRUE)
+    result <- gsub("%", "\\%", result, fixed = TRUE)
+    result <- gsub("&", "\\&", result, fixed = TRUE)
+    result <- gsub("_", "\\_", result, fixed = TRUE)
+    result <- gsub("#", "\\#", result, fixed = TRUE)
+    result <- gsub("^", "\\verb|^|", result, fixed = TRUE)
+    result <- gsub("~", "\\~{}", result, fixed = TRUE)
+    result <- gsub("SANITIZE.BACKSLASH", "$\\backslash$",
       result, fixed = TRUE)
   }
-  else if (type == 'html'){
-    result <- gsub('&', '&amp;', result, fixed = TRUE)
-    result <- gsub('>', '&gt;', result, fixed = TRUE)
-    result <- gsub('<', '&lt;', result, fixed = TRUE)
+  else if (type == "html"){
+    result <- gsub("&", "&amp;", result, fixed = TRUE)
+    result <- gsub(">", "&gt;", result, fixed = TRUE)
+    result <- gsub("<", "&lt;", result, fixed = TRUE)
   } else {
-    result <- gsub('\\', '\\\\', result, fixed = TRUE)
-    result <- gsub('{', '\\{', result, fixed = TRUE)
-    result <- gsub('}', '\\}', result, fixed = TRUE)
+    result <- gsub("\\", "\\\\", result, fixed = TRUE)
+    result <- gsub("{", "\\{", result, fixed = TRUE)
+    result <- gsub("}", "\\}", result, fixed = TRUE)
   }
 
   return(result)
@@ -106,24 +106,25 @@ sanitize <- function (str, type = c('latex', 'html', 'rtf')) {
 hux_logo <- function(latex = FALSE, html = FALSE) {
   assert_that(is.flag(latex))
 
-  blank <- if (html) '&nbsp;' else ''
+  blank <- if (html) "&nbsp;" else ""
   squares <- rep(blank, 36)
   letter_squares <- sort(sample(36, 8))
-  squares[letter_squares] <- strsplit('huxtable', '')[[1]]
+  squares[letter_squares] <- strsplit("huxtable", "")[[1]]
   mx <- matrix(squares, 6, 6, byrow = TRUE)
   letter_squares <- which(mx != blank) # back in vertical space
-  h_square <- which(mx == 'h')
+  h_square <- which(mx == "h")
 
   mondrian <- as_hux(mx)
   escape_contents(mondrian) <- FALSE
-  align(mondrian) <- 'centre'
-  font(mondrian) <- 'Arial'
-  if (latex) font(mondrian) <- 'cmss'
+  align(mondrian) <- "centre"
+  font(mondrian) <- "Arial"
+  if (latex) font(mondrian) <- "cmss"
   mondrian <- set_all_borders(mondrian, if (html) 2 else 1.2)
   mondrian <- set_all_padding(mondrian, 0)
-  mondrian <- set_all_border_colors(mondrian, 'black')
-  background_color(mondrian)[sample(36, 8)] <- sample(c('red', 'blue', 'yellow'), 8, replace = TRUE)
-  mondrian <- set_text_color(mondrian, where(background_color(mondrian) == 'blue'), 'white')
+  mondrian <- set_all_border_colors(mondrian, "black")
+  bg_cells <- sample(36, 8)
+  background_color(mondrian)[bg_cells] <- sample(c("red", "blue", "yellow"), 8, replace = TRUE)
+  text_color(mondrian)[bg_cells] <- "white"
   bold(mondrian)[h_square] <- TRUE
 
   colspan_ok <- setdiff(1:30, letter_squares - 6)
@@ -148,31 +149,30 @@ hux_logo <- function(latex = FALSE, html = FALSE) {
 
   if (html) {
     mondrian <- set_all_padding(mondrian, 2)
-    width(mondrian)  <- '120pt'
-    height(mondrian) <- '120pt'
-    col_width(mondrian)  <- '20pt'
-    row_height(mondrian) <- '20pt'
+    width(mondrian)  <- "120pt"
+    height(mondrian) <- "120pt"
+    col_width(mondrian)  <- "20pt"
+    row_height(mondrian) <- "20pt"
   }
 
   mondrian
 }
 
 
+#' @export
+#' @rdname huxtable-deprecated
+hux_hex <- function () {
+  .Deprecated("hex_hux")
+}
+
 
 #' @export
-#' @rdname hux_logo
-#' @details
-#' All modern packages should have a hex logo. Run `hux_hex` if you wish to produce one.
-hux_hex <- function () {
-  hell_no <- hux(c('We don\'t', 'stinkin\''), c('need no', 'hexes'))
-  hell_no <- set_all_borders(hell_no, 1)
-  hell_no <- set_all_border_colors(hell_no, 'red')
-  background_color(hell_no) <- 'black'
-  text_color(hell_no) <- 'red'
-
-  hell_no
+#' @rdname huxtable-deprecated
+hex_hux <- function () {
+  .Deprecated("hux_hex")
 }
 
+
 #' Default print method for huxtables
 #'
 #' By default huxtables are printed using [print_screen()]. In certain cases, for example
@@ -188,13 +188,11 @@ hux_hex <- function () {
 #'   `options("huxtable.knitr_output_format")` in [huxtable-options]
 #' @examples
 #' \dontrun{
-#' # to print LaTeX output:
-#' options(huxtable.print = print_latex)
-#' # to print huxtables like data frames:
-#' options(huxtable.print = function(x, ...) print(as.data.frame(x)))
+#'   # to print LaTeX output:
+#'   options(huxtable.print = print_latex)
 #' }
 print.huxtable <- function(x, ...) {
-  meth <- getOption('huxtable.print', default = print_screen)
+  meth <- getOption("huxtable.print", default = print_screen)
   if (is.character(meth)) meth <- eval(as.symbol(meth))
 
   meth(x, ...)
@@ -202,18 +200,18 @@ print.huxtable <- function(x, ...) {
 
 
 #' @rdname print.huxtable
-#' @param output One of `"html"`, `"latex"`, `"md"` or `"screen"`
+#' @param output Output format. One of `"html"`, `"latex"`, `"md"`, `"screen"` or `"rtf"`.
 #'
 #' @return `format` returns a string representation from [to_latex()], [to_html()] etc.
 #' @export
 #'
 #' @examples
-#' ht <- hux(a = 1:3, b = 4:6)
-#' format(ht, output = 'screen')
-#' format(ht, output = 'md')
-format.huxtable <- function(x, ..., output) {
-  assert_that(is.string(output))
-  assert_that(output %in% c('latex', 'html', 'md', 'screen'))
-  fn <- paste0('to_', output)
+#'
+#' format(jams, output = "screen")
+#' format(jams, output = "md")
+format.huxtable <- function(x, ..., output = c("latex", "html", "md", "screen", "rtf")) {
+  output <- match.arg(output)
+
+  fn <- paste0("to_", output)
   do.call(fn, list(ht = x, ...))
 }
